@@ -26,6 +26,7 @@ EXTENSIONS = {
     'cpp': {'text', 'c++'},
     'crt': {'text', 'pem'},
     'cs': {'text', 'c#'},
+    'csh': {'text', 'shell', 'csh'},
     'cson': {'text', 'cson'},
     'css': {'text', 'css'},
     'csv': {'text', 'csv'},
@@ -155,6 +156,7 @@ EXTENSIONS = {
     'tiff': {'binary', 'image', 'tiff'},
     'toml': {'text', 'toml'},
     'tf': {'text', 'terraform'},
+    'tfvars': {'text', 'terraform'},
     'ts': {'text', 'ts'},
     'tsx': {'text', 'tsx'},
     'ttf': {'binary', 'ttf'},
@@ -197,6 +199,7 @@ NAMES = {
     '.bash_profile': EXTENSIONS['bash'],
     '.bowerrc': EXTENSIONS['json'] | {'bowerrc'},
     '.coveragerc': EXTENSIONS['ini'] | {'coveragerc'},
+    '.cshrc': EXTENSIONS['csh'],
     '.dockerignore': {'text', 'dockerignore'},
     '.editorconfig': {'text', 'editorconfig'},
     '.gitconfig': EXTENSIONS['ini'] | {'gitconfig'},
